#!/bin/bash
# Do restore from backup path using specified method
# Usage: do-restore.sh <system> <method> <backup_path>

. /usr/share/synbak/functions.sh
. "${0%/*}/synbak-utils-functions.sh"

[ -z "$3" ] && echo "Error: missing <backup_path>" && exit 1

backup_path="$3"

check_usr_file_conf

case "$method" in
    tar)
	tar -C / -xf "$backup_path" || exit 1
	;;
    rsync)
	file_config_field_import "$usr_file_conf" backup_incremental boolean notnull
	# If backup is incremental and used not last copy, first restore base copy
	if [ x"$backup_incremental" = x"yes" ]; then
	    [ "${backup_path##*/}" = "backup-$system" ] || \
	    rsync -avPH "${backup_path%/*}/backup-$system"/ /
	fi
	# Then restore from specified copy
	rsync -avPH "$backup_path"/ /
	;;
    *)
	echo "Error: unsupported method '$method'" > /dev/stderr
	exit 2
	;;
esac
